==> foundation-1.0.1.tgz: package/lib/esm/Stack.js <==
var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { jsx as _jsx } from "@emotion/react/jsx-runtime";
import { css, useTheme } from "@emotion/react";
import { forwardRef } from "react";
import useSs from "./useSs";
var alignments = {
    stretch: "stretch",
    left: "flex-start",
    right: "flex-end",
    center: "center",
};
export default forwardRef(function (props, ref) {
    var _a, _b;
    var size = useTheme().size;
    var ss = useSs(props);
    return (_jsx("div", __assign({ css: css(ss, css(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n          display: flex;\n          flex-direction: column;\n          align-items: ", ";\n        "], ["\n          display: flex;\n          flex-direction: column;\n          align-items: ", ";\n        "])), alignments[(_a = props.alignX) !== null && _a !== void 0 ? _a : "stretch"]), { rowGap: props.gap === null ? undefined : size((_b = props.gap) !== null && _b !== void 0 ? _b : "md").raw }), ref: ref, className: props.className }, { children: props.children })));
});
var templateObject_1;

==> foundation-1.0.4.tgz: package/lib/esm/Stack.js <==
var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { jsx as _jsx } from "@emotion/react/jsx-runtime";
import { css } from "@emotion/react";
import useTheme from "./useTheme";
import { forwardRef } from "react";
import useSs from "./useSs";
var alignments = {
    stretch: "stretch",
    left: "flex-start",
    right: "flex-end",
    center: "center",
};
export default forwardRef(function (props, ref) {
    var _a, _b;
    var size = useTheme().size;
    var ss = useSs(props);
    return (_jsx("div", __assign({ css: css(ss, css(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n          display: flex;\n          flex-direction: column;\n          align-items: ", ";\n        "], ["\n          display: flex;\n          flex-direction: column;\n          align-items: ", ";\n        "])), alignments[(_a = props.alignX) !== null && _a !== void 0 ? _a : "stretch"]), { rowGap: props.gap === null ? undefined : size((_b = props.gap) !== null && _b !== void 0 ? _b : "md").raw }), ref: ref, className: props.className }, { children: props.children })));
});
var templateObject_1;
